@@ -2,6 +2,7 @@
 *  gcal2txt.c:  Creates a verbatim text file from a Gcal resource file.
 *
 *
+*  Copyright (c) 2000-2010 Free Software Foundation, Inc.
 *  Copyright (c) 1996, 1997, 2000 Thomas Esken
 *
 *  This software doesn't claim completeness, correctness or usability.
@@ -623,7 +624,7 @@ main (argc, argv)
   /*
      Now initialize the NLS functions.
    */
-# if HAVE_SETstaticE
+# if HAVE_SETLOCALE
   setlocale (LC_ALL, "");
 # endif
 # ifndef LOCALEDIR
